# XChainPy2 Wallet package

This package allows to assemble several blockchain clients in a single wallet object.
You can install only the clients you need.

### Documentation

👉 https://xchainpy2.readthedocs.io/en/latest/packages/xchainpy2_wallet.html


